@@ -2,7 +2,7 @@
  *
  * $Id: translator_nl.h,v 1.22 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -74,7 +74,7 @@ class TranslatorDutch : public Translator
     QCString trGeneratedAutomatically(const char *s)
     { QCString result="Automatisch gegenereerd door Doxygen"; 
       if (s) result+=(QCString)" voor "+s;
-      result+=" uit de programmacode."; 
+      result+=" uit de programmatekst."; 
       return result;
     }
     QCString trEnumName()
@@ -91,8 +91,6 @@ class TranslatorDutch : public Translator
     { return "Klasse Lijst"; }
     QCString trFileList()
     { return "File Lijst"; }
-    QCString trHeaderFiles()
-    { return "Header Lijst"; }
     QCString trCompoundMembers()
     { return "Klasse Members"; }
     QCString trFileMembers()
@@ -111,7 +109,7 @@ class TranslatorDutch : public Translator
     {
       QCString result="Hieronder volgt de lijst met alle ";
       if (!extractAll) result+="gedocumenteerde ";
-      result+="files, elk met een korte beschrijving:";
+      result+="bestanden, elk met een korte beschrijving:";
       return result;
     }
     QCString trCompoundListDescription()
@@ -131,21 +129,17 @@ class TranslatorDutch : public Translator
     {
       QCString result="Hieronder volgt de lijst met alle ";
       if (!extractAll) result+="gedocumenteerde ";
-      result+="file members met links naar ";
-      if (extractAll) result+="de file documentatie voor elke member:";
-      else result+="de files waartoe ze behoren:";
+      result+="bestand members met links naar ";
+      if (extractAll) result+="de bestand's documentatie voor elke member:";
+      else result+="de bestanden waartoe ze behoren:";
       return result;
     }
-    QCString trHeaderFilesDescription()
-    { return "Hieronder volgen de header files die de API vormen:"; }
     QCString trExamplesDescription()
     { return "Hieronder volgt de lijst met alle voorbeelden:"; }
     QCString trRelatedPagesDescription()
     { return "Hieronder volgt de lijst met alle pagina's die gerelateerde documentatie bevatten:"; }
     QCString trModulesDescription()
     { return "Hieronder volgt de lijst met alle modules:"; }
-    QCString trNoDescriptionAvailable()
-    { return "Geen korte beschrijving beschikbaar"; }
 
     QCString trDocumentation()
     { return "Documentatie"; }
@@ -217,14 +211,8 @@ class TranslatorDutch : public Translator
     }
     QCString trForInternalUseOnly()
     { return "Alleen voor intern gebruik."; }
-    QCString trReimplementedForInternalReasons()
-    { return "Om interne redenen opnieuwd ge&iuml;mplemented; "
-             "de API wordt er niet door be&iuml;nvloed."; 
-    }
     QCString trWarning()
     { return "Waarschuwing"; }
-    QCString trBugsAndLimitations()
-    { return "Fouten en beperkingen"; }
     QCString trVersion()
     { return "Versie"; }
     QCString trDate()
@@ -291,7 +279,7 @@ class TranslatorDutch : public Translator
       // used as the title of the HTML page of a file
     {
       QCString result=fileName;
-      result+=" File Referentie"; 
+      result+=" Bestand Referentie"; 
       return result;
     }
     QCString trNamespaceReference(const char *namespaceName)
@@ -421,18 +409,18 @@ class TranslatorDutch : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"De documentatie voor deze ";
+      QCString result=(QCString)"De documentatie voor ";
       switch(compType)
       {
-        case ClassDef::Class:      result+="class"; break;
-        case ClassDef::Struct:     result+="struct"; break;
-        case ClassDef::Union:      result+="union"; break;
-        case ClassDef::Interface:  result+="interface"; break;
-        case ClassDef::Protocol:   result+="protocol"; break;
-        case ClassDef::Category:   result+="category"; break;
-        case ClassDef::Exception:  result+="exception"; break;
+        case ClassDef::Class:      result+="deze klasse"; break;
+        case ClassDef::Struct:     result+="deze struct"; break;
+        case ClassDef::Union:      result+="deze union"; break;
+        case ClassDef::Interface:  result+="dit interface"; break;
+        case ClassDef::Protocol:   result+="dit protocol"; break;
+        case ClassDef::Category:   result+="deze categorie"; break;
+        case ClassDef::Exception:  result+="deze exceptie"; break;
       }
-      result+=" is gegenereerd op grond van de volgende file";
+      result+=" is gegenereerd op grond van het volgende bestand";
       if (single) result+=":"; else result+="s:";
       return result;
     }
@@ -466,17 +454,13 @@ class TranslatorDutch : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Broncode";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
-      return "De definitie bevindt zich op regel @0 in de file @1.";
+      return "De definitie bevindt zich op regel @0 in het bestand @1.";
     }
     QCString trDefinedInSourceFile()
     {
-      return "De definitie bevindt zich in de file @0.";
+      return "De definitie bevindt zich in het bestand @0.";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -510,12 +494,12 @@ class TranslatorDutch : public Translator
     /*! Used in the file documentation to point to the corresponding sources. */
     QCString trGotoSourceCode()
     {
-      return "Ga naar de bron code van deze file.";
+      return "Ga naar de broncode van dit bestand.";
     }
     /*! Used in the file sources to point to the corresponding documentation. */
     QCString trGotoDocumentation()
     {
-      return "Ga naar de documentatie van deze file.";
+      return "Ga naar de documentatie van dit bestand.";
     }
     /*! Text for the \\pre command */
     QCString trPrecondition()
@@ -638,8 +622,8 @@ class TranslatorDutch : public Translator
     }
     QCString trInclByDepGraph()
     {
-      return "Deze graaf geeft aan welke files direct of "
-             "indirect afhankelijk zijn van deze file:";
+      return "Deze graaf geeft aan welke bestanden direct of "
+             "indirect afhankelijk zijn van dit bestand:";
     }
     QCString trSince()
     {
@@ -671,6 +655,8 @@ class TranslatorDutch : public Translator
         "class Undocumented { };\n\n"
         "/*! Klasse met public inheritance */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! A template class */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Klasse met protected inheritance */\n"
         "class ProtectedBase { };\n\n"
         "/*! Klasse met private inheritance */\n"
@@ -681,19 +667,19 @@ class TranslatorDutch : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
         "};\n"
         "\\endcode\n"
-        "Als de \\c MAX_DOT_GRAPH_HEIGHT tag in the configuratie file "
-        "op 200 gezet is, zal het bestaande voorbeeld resulteren in de volgende graaf:"
+        "Dit voorbeeld zal resulteren in de volgende graaf:"
         "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
         "<p>\n"
         "De rechthoeken in the bovenstaande graaf hebben de volgende betekenis:\n"
         "<ul>\n"
-        "<li>Een gevulde zwarte rechthoek representeert de structure of klasse waarvoor "
+        "<li>Een gevulde grijze rechthoek representeert de structure of klasse waarvoor "
         "de graaf is gegeneerd.\n"
         "<li>Een rechthoek met een zwarte rand representeert een gedocumenteerde structure of klasse.\n"
         "<li>Een rechthoek met een grijze rand representeert een ongedocumenteerde structure of klasse.\n"
@@ -765,11 +751,6 @@ class TranslatorDutch : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    QCString trInterfaces()
-    {
-      return "Interfaces";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     QCString trClasses()
     {
@@ -795,11 +776,6 @@ class TranslatorDutch : public Translator
     {
       return "Packages";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    QCString trPackageDocumentation()
-    {
-      return "Package Documentatie";
-    }
     /*! Text shown before a multi-line define */
     QCString trDefineValue()
     {
@@ -887,8 +863,8 @@ class TranslatorDutch : public Translator
      */
     virtual QCString trFile(bool first_capital, bool singular)
     { 
-      QCString result((first_capital ? "File" : "file"));
-      if (!singular)  result+="s";
+      QCString result((first_capital ? "Bestand" : "bestand"));
+      if (!singular)  result+="en";
       return result; 
     }
 
@@ -936,17 +912,6 @@ class TranslatorDutch : public Translator
       return result; 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Veld" : "veld"));
-      if (!singular)  result+="en";
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1200,7 +1165,250 @@ class TranslatorDutch : public Translator
       return result; 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a function.
+     */
+    virtual QCString trOverloadText()
+    {
+      return "Deze functie is overloaded en is beschikbaar gemaakt om het "
+             "gebruik te vergemakkelijken. Ze verschilt alleen van de "
+             "bovenstaande functie wat betreft de parameterlijst.";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallerGraph()
+    {
+      return "Hier is de caller graaf voor deze functie:";
+    }
     
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return "Member Function/Subroutine Documentation"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return "Lijst met data types"; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return "Data velden"; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return "Hieronder volgen de data types elk een korte beschrijving:"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+      QCString result="Hieronder volgt de lijst met alle ";
+      if (!extractAll) result+="gedocumenteerde ";
+      result+="data types met links naar ";
+      if (!extractAll) result+="de klasse documentatie voor elke member:";
+      else result+="de klassen waartoe ze behoren:";
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    { return "Data Type Index"; }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    { return "Data Type Documentatie"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    { return "Functies/Subroutines"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    { return "Functie/Subroutine Documentatie"; }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    { return "Data Types"; }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return "Module Lijst"; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result="Hieronder volgt de lijst met alle ";
+      if (!extractAll) result+="gedocumenteerde ";
+      result+="modulen, elk met een korte beschrijving:";
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      QCString result=(QCString)clName;
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=" Module"; break;
+        case ClassDef::Struct:     result+=" Type"; break;
+        case ClassDef::Union:      result+=" Union"; break;
+        case ClassDef::Interface:  result+=" Interface"; break;
+        case ClassDef::Protocol:   result+=" Protocol"; break;
+        case ClassDef::Category:   result+=" Category"; break;
+        case ClassDef::Exception:  result+=" Exception"; break;
+      }
+      if (isTemplate) result+=" Template";
+      result+=" Referentie";
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+=" Module Referentie";        
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return "Module Members"; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result="Hier is een lijst van alle ";
+      if (!extractAll) result+="gedocumenteerde ";
+      result+="module members met links naar ";
+      if (extractAll) 
+        result+="de module documentatie voor iedere member:";
+      else 
+        result+="de module waartoe ze behoren:";
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    { return "Module Index"; }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool first_capital, bool singular)
+    {       
+      QCString result((first_capital ? "Module" : "module"));
+      if (!singular)  result+="n";
+      return result; 
+    }
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool single)
+    { // here s is one of " Class", " Struct" or " Union"
+      // single is true implies a single file
+      QCString result=(QCString)"De documentatie voor ";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="deze module"; break;
+        case ClassDef::Struct:     result+="dit type"; break;
+        case ClassDef::Union:      result+="deze union"; break;
+        case ClassDef::Interface:  result+="dit interface"; break;
+        case ClassDef::Protocol:   result+="dit protocol"; break;
+        case ClassDef::Category:   result+="deze category"; break;
+        case ClassDef::Exception:  result+="deze exception"; break;
+      }
+      result+=" is gegenereerd op grond van het volgende bestand";
+      if (single) result+=":"; else result+="s:";
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Type" : "type"));
+      if (!singular)  result+="s";
+      return result; 
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Subprogramma" : "subprogramma"));
+      if (!singular)  result+="s";
+      return result; 
+    }
+
+    /*! C# Type Contraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "Type Beperkingen";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.0
+//////////////////////////////////////////////////////////////////////////
+
+    /*! directory relation for \a name */
+    virtual QCString trDirRelation(const char *name)
+    {
+      return QCString(name)+" Relatie";
+    }
+
+    /*! Loading message shown when loading search results */
+    virtual QCString trLoading()
+    {
+      return "Laden...";
+    }
+
+    /*! Label used for search results in the global namespace */
+    virtual QCString trGlobalNamespace()
+    {
+      return "Globale Namespace";
+    }
+
+    /*! Message shown while searching */
+    virtual QCString trSearching()
+    {
+      return "Zoeken...";
+    }
+
+    /*! Text shown when no search results are found */
+    virtual QCString trNoMatches()
+    {
+      return "Niets gevonden";
+    }
+
+
+
 };
 
 #endif
